# -*- coding: utf-8 -*-
#
# Created on Oct 15, 2013
# @author: Jiri Spilka
# http://bio.felk.cvut.cz/~spilkaj
# 2013, CTU in Prague, FEE, Dept. of Cybernetics
#
# Licensed under the terms of the GNU GENERAL PUBLIC LICENSE
# (see ctgViewerLite.py for details)

from os.path import expanduser, join
from datetime import datetime
import logging
import Common
import ConfigParser
import os
import shutil

class ConfigIni():

    def __init__(self):
        self._configParser = ConfigParser.ConfigParser()

        self._log = logging.getLogger(ConfigStatic.logger_name)

        self.dirLastUsed = ''
        self.dockClinInformationVisible = 0
        self.dataBrowserSelectedAttributes = ''

        self._lSections = ['Directories','GUI']

        self.__ensure_settings_ini()
        self.read_config()

    def __ensure_settings_ini(self):
        default_ini = 'default.ini'
        app_path = Common.get_application_path()
        file2copy = os.path.join(app_path,default_ini)
        if not Common.file_exists(ConfigStatic.setting_file):
            shutil.copy(file2copy, ConfigStatic.setting_file)
            self._log.info("ConfigStatic file not exists, copy from application path")

    def read_config(self, ini_file = None):

        if ini_file is None:
            ini_file = ConfigStatic.setting_file

        self._log.info("reading config file {0}".format(ini_file))
        if not Common.file_exists(ini_file):
            return

        self._configParser.read(ConfigStatic.setting_file)
        try:
            self.dirLastUsed = self._configParser.get('Directories', 'lastUsedDirFiles')
            self.dockClinInformationVisible = self._configParser.getboolean('GUI', 'dockClinInformationVisible')
            self.dataBrowserSelectedAttributes = self._configParser.get('GUI', 'dataBrowserSelectedAttributes')
        except Exception, e:
            raise Exception('Error when reading config file {0}, message:{1}'.format(ini_file,e))

    def write_config(self):
        # lets create that config file for next time...
        cfgf = open(ConfigStatic.setting_file, 'w')

        # add the settings to the structure of the file, and lets write it out...
        for l in self._lSections:
            try:
                self._configParser.add_section(l)
            except Exception,msg:
                self._log.info("A section exist {0}".format(msg))

        self._configParser.set('GUI', 'dockClinInformationVisible', self.dockClinInformationVisible)
        self._configParser.set('GUI', 'dataBrowserSelectedAttributes', self.dataBrowserSelectedAttributes)
        self._configParser.set('Directories', 'lastUsedDirFiles', self.dirLastUsed)

        self._configParser.write(cfgf)
        cfgf.close()

        self._log.info("Ini file has been written successfully")

class ConfigStatic:

    version = 0.02
    _configParser = ConfigParser.ConfigParser()

    user_directory = expanduser("~/.ctgViewerLite")

    # logging
    logging_level = logging.ERROR
    logger_name = 'ctgViewerLite'
    log_path = join(user_directory,'logs')
    log_name = 'log_' + datetime.today().strftime("%Y-%m-%d_%H-%M-%S") + '.log'
    log_file = join(log_path, log_name)

    #temp directory
    temp_data = join(user_directory,'temp_data')

    # date time format
    date_format = '%d.%m.%Y'
    time_format = '%H:%M:%S:%f'

    setting_file = join(user_directory,'settings.ini')