# -*- coding: utf-8 -*-
#
# Created on Oct 15, 2013
# @author: Jiri Spilka
# http://bio.felk.cvut.cz/~spilkaj
# 2013, CTU in Prague, FEE, Dept. of Cybernetics
#
# Licensed under the terms of the GNU GENERAL PUBLIC LICENSE
# (see ctgViewerLite.py for details)


from PyQt4 import QtGui, Qt
import sys
import os

from AboutGui import Ui_DialogAbout
from ConvertFileGui import Ui_ConvertFile
from LoadWriteData import LoadData
import ClinInfo
import Common

class AboutDialog(QtGui.QDialog):

    def __init__(self, parent=None):
        QtGui.QDialog.__init__(self)
        self.ui = Ui_DialogAbout()
        self.ui.setupUi(self)

        pal = QtGui.QPalette()
        pal.setColor(QtGui.QPalette.Base, pal.background().color())
        self.ui.textBrowser.setPalette(pal);

        self.ui.textBrowser.setOpenExternalLinks(True)

        #self.ui.label.setPixmap(QtGui.QPixmap('images/BioDat_logo_final_small.jpg'))

        #self.ui.textEdit.setReadOnly(False)
        #print self.ui.textEdit.textColor()
        #self.ui.textEdit.setTextBackgroundColor(a)
        #self.ui.textEdit.setTextColor(a)
        #print self.ui.textEdit.textColor()

        #print self.ui.textEdit.isReadOnly()





class ConvertFileForm(QtGui.QWidget):

    def __init__(self, parent=None):
        QtGui.QWidget.__init__(self)

        self.ui = Ui_ConvertFile()
        self.ui.setupUi(self)

        pal = QtGui.QPalette()
        pal.setColor(QtGui.QPalette.Base, pal.background().color())
        self.ui.textEditInfo.setPalette(pal);

        self.listAllowedFormats = ['dat','csv','mat', 'txt']
        self.listFormatTooltips = ['physionet format','comma separated value','matlab format','BDI txt']

        self._filesToConvert = []
        self._dataLoader = LoadData()


        self._setupComboBoxes()

        self.ui.btnBrowseSource.clicked.connect(self._openDirectorySource)
        self.ui.btnBrowseDest.clicked.connect(self._openDirectoryDest)
        self.ui.btnConvert.clicked.connect(self._convert)

        self.msgBoxError = QtGui.QMessageBox()
        self.msgBoxError.setDefaultButton(QtGui.QMessageBox.Close)
        self.msgBoxError.setIcon(QtGui.QMessageBox.Critical)

        #self.ui.lnSource.editingFinished.connect(self.checkSourceDirForFiles)

    def _setupComboBoxes(self):

        cnt = 0
        self.ui.cbFrom.addItem('dat')
        self.ui.cbTo.addItem('csv')

        #for l in self.listAllowedFormats:
        #    self.ui.cbFrom.addItem(l)
        #    self.ui.cbTo.addItem(l)
        #    self.ui.cbFrom.setItemData(cnt, self.listFormatTooltips[cnt], Qt.Qt.ToolTipRole)
        #    self.ui.cbTo.setItemData(cnt, self.listFormatTooltips[cnt], Qt.Qt.ToolTipRole)
        #    cnt += 1

        self.ui.cbFrom.setCurrentIndex(0)
        self.ui.cbTo.setCurrentIndex(0)


    def _openDirectorySource(self):
        open_dialog = QtGui.QFileDialog(self, 'Open directory', '')
        dir1 = open_dialog.getExistingDirectory()

        if dir == "":
            return -1
        else:
            dir1 = str(dir1)
            self.ui.lnSource.setText(dir1)
            self.checkSourceDirForFiles()

        return 0



    def _openDirectoryDest(self):
        open_dialog = QtGui.QFileDialog(self, 'Open directory', '')
        dir1 = open_dialog.getExistingDirectory()

        if dir == "":
            return -1
        else:
            dir1 = str(dir1)
            self.ui.lnDestination.setText(dir1)

        return 0

    def checkDirectoryExists(self,dir1):

        if not os.path.exists(dir1):
            self.msgBoxError.setText('Directory not exists')
            self.msgBoxError.exec_()
            return

    def checkSourceDirForFiles(self):

        dir1 = str(self.ui.lnSource.text())
        ext_mask = str(self.ui.cbFrom.itemText(self.ui.cbFrom.currentIndex()))

        self.checkDirectoryExists(dir1)

        files = Common.get_files_with_ext_mask(dir1,ext_mask)
        files.sort()

        self.ui.labFile2Convert.setText(str(len(files)))
        self._filesToConvert = files

    def _convert(self):

        self.ui.textEditInfo.clear()

        # check source files
        extFrom = str(self.ui.cbFrom.itemText(self.ui.cbFrom.currentIndex()))
        extTo = str(self.ui.cbFrom.itemText(self.ui.cbTo.currentIndex()))

        if extFrom == extTo:
            self.msgBoxError.setText('Cannot convert to the same format')
            self.msgBoxError.show()

        dir1 = str(self.ui.lnSource.text())
        dir2 = str(self.ui.lnDestination.text())

        self.checkDirectoryExists(dir1)
        self.checkDirectoryExists(dir2)

        self.checkSourceDirForFiles()

        if self._filesToConvert == 0:
            self.msgBoxError.setText('No files with format {0} in specified directory {1}',extFrom,dir1)
            self.msgB
            return

        if extTo == 'csv':
            sFileClinicalInfo = os.path.join(dir2,('clinical_information.csv'))
            fClinInfo = open(sFileClinicalInfo,'w+')

            cnt = 0
            for s in ClinInfo.list_clin_info:
                fClinInfo.write(s)
                cnt += 1
                if cnt == len(ClinInfo.list_clin_info):
                    fClinInfo.write('\n')
                else:
                    fClinInfo.write(',')

        # run conversion
        for f in self._filesToConvert:

            # convert FROM
            if extFrom == 'dat':
                aDataAll, lHeader = self._dataLoader.readPhysionetSignal16(f)

            # convert TO
            if extTo == 'dat':
                self.msgBoxError.setText('Not supported yet')
                self.msgBoxError.exec_()

            if extTo == 'csv':
                # file name
                try:
                    file_name = Common.get_filename_without_ext(f)
                    name_new = os.path.join(dir2,(file_name+'.'+extTo))

                    # data fhr, uc
                    self._dataLoader.writeCsvFile(name_new, aDataAll)

                    # clinical information
                    cnt = 0
                    dictInfo = lHeader[2]
                    for l in ClinInfo.list_clin_info:
                        if l in dictInfo:
                            fClinInfo.write(str(dictInfo[l]))
                        else:
                            fClinInfo.write('')

                        cnt += 1
                        if cnt == len(ClinInfo.list_clin_info):
                            fClinInfo.write('\n')
                        else:
                            fClinInfo.write(',')

                    self.ui.textEditInfo.append('File {0} - Converted'.format(file_name+'.'+extTo))
                    self.ui.textEditInfo.repaint()
                except Exception,msg:
                    self.ui.textEditInfo.append('File {0} - ERROR: {1}'.format(file_name+'.'+extTo,msg))

        if extTo == 'csv':
            self.ui.textEditInfo.append('All files converted successfully')
            self.ui.textEditInfo.append('Clinical information were saved into file: {0}'.format(sFileClinicalInfo))
            fClinInfo.close()


def main():
    app = QtGui.QApplication(sys.argv)
    window = ConvertFileForm()
    window.show()
    sys.exit(app.exec_())

if __name__ == '__main__':
        main()
